.. _examples:

======================
Examples
======================

CTQW Examples
-------------------------

.. toctree::
	:maxdepth: 1
	:glob:

	examples/*P_line/*
	examples/*P_3cayley/*
	examples/*P_sr/*


Graph Isomorphism Examples
----------------------------

.. toctree::
	:maxdepth: 1
	:glob:

	examples/GraphISO*/*


Fortran Examples
----------------------------

.. toctree::
	:maxdepth: 1
	:glob:

	examples/exampleMPI*/*
